import time
import terminalio
import displayio
import vectorio
from adafruit_display_text import label

def graph_data( spectral_data_sorted, graph_bar, graph_bar_x, polygon ):
    if spectral_data_sorted:
        y_zero_pixels = 108
        y_upper_pixels = 20
        graph_points = [(2, 112), (2, 104)]
        y_span_pixels = y_zero_pixels - y_upper_pixels
        irradiances = spectral_data_sorted
        irrad_min = min( irradiances )
        irrad_max = max( irradiances )
        irrad_span = irrad_max - irrad_min
        if irrad_span < 1:
            irrad_span = 1
        for count in range (len( irradiances )):
            irrad_value = irradiances[ count ]
            irrad_height = irrad_value - irrad_min
            irrad_normalized_height = irrad_height/ irrad_span
            irrad_bar_height_pixels = int(y_span_pixels * irrad_normalized_height)
            irrad_drop_height_pixels = int(y_span_pixels - irrad_bar_height_pixels)
            irrad_y_top_pixel = int(y_upper_pixels + irrad_drop_height_pixels)
            graph_bar[count].y = irrad_y_top_pixel
            graph_bar[count].height = 4
            point = (graph_bar_x[count]+1, irrad_y_top_pixel)
            graph_points.append(point)
        graph_points.append((126, 104))
        graph_points.append((126, 112))
        polygon.points = graph_points
        del y_zero_pixels, y_upper_pixels, graph_points, y_span_pixels, irradiances, spectral_data_sorted
        del irrad_min, irrad_max, irrad_span, count, irrad_value, irrad_height
        del irrad_normalized_height, irrad_bar_height_pixels, irrad_drop_height_pixels
        del irrad_y_top_pixel, point

def create_graph_screen( display_group, bands_sorted ):
    if display_group is not False:
        palette = displayio.Palette(1)
        palette[0] = 0x999999
        points2 = [ (2, 112), (2, 104), (126, 104), (126, 112)]
        polygon = vectorio.Polygon(pixel_shader=palette, points=points2, x=0, y=0)
        display_group.append( polygon )
        bar_color = 0xFFFFFF
        bar = displayio.Palette(1)
        bar[0] = bar_color
        bar_width = 4
        bar_default_height = 2
        graph_bar_x = (0, 6, 12, 18, 24, 29, 35, 41, 47, 55, 63, 69, 75, 82, 93, 105, 114, 124)
        graph_bar=[]
        for count in range( len( bands_sorted)):
            graph_bar.append( vectorio.Rectangle(pixel_shader=bar, width=bar_width, height=bar_default_height, x=graph_bar_x[count], y=106))
            display_group.append( graph_bar[count] )

        color_label_group = displayio.Group( scale=1, x=4, y=119)
        color_label_text = "V B G YO  R   NIR "
        color_label_text_area = label.Label( terminalio.FONT, text=color_label_text, color=0xFFFFFF )
        color_label_group.append( color_label_text_area )
        display_group.append( color_label_group )

        wavelength_label_group = displayio.Group( scale=1, x=4, y=9)
        wavelength_label_text = "410nm          940nm"
        wavelength_label_text_area = label.Label( terminalio.FONT, text=wavelength_label_text, color=0xFFFFFF )
        wavelength_label_group.append( wavelength_label_text_area )
        display_group.append( wavelength_label_group )

        batch_number_label_group = displayio.Group( scale=1, x=40, y=9)
        batch_number_label_text = "batch:0"
        batch_number_label_text_area = label.Label( terminalio.FONT, text=batch_number_label_text, color=0xFFFFFF )
        batch_number_label_group.append( batch_number_label_text_area )
        display_group.append( batch_number_label_group )

        recording_rectangle_width = 20
        recording_rectangle_height = 15
        recording_rectangle_x = 128-recording_rectangle_width
        recording_rectangle_y = 128-recording_rectangle_height
        recording_rectangle_color = 0xFFFFFF
        recording = displayio.Palette(1)
        recording[0] = recording_rectangle_color
        recording_rectangle = vectorio.Rectangle( pixel_shader=recording, width=recording_rectangle_width, height=recording_rectangle_height, x=recording_rectangle_x, y=recording_rectangle_y)
        recording_rectangle.hidden = True
        display_group.append( recording_rectangle )

        recording_label_group = displayio.Group( scale=1, x=recording_rectangle_x + 2 , y=recording_rectangle_y+7)
        recording_label_text = "REC"
        recording_label_text_area = label.Label( terminalio.FONT, text=recording_label_text, color=0x000000 )
        recording_label_group.append( recording_label_text_area )
        recording_label_text_area.hidden = True
        display_group.append( recording_label_group )

        overlay_rectangle = False
        overlay_text_area = False
        overlay_width = 120
        overlay_height = 40
        overlay_x = 10
        overlay_y = 40
        overlay_color = 0x000000
        overlay = displayio.Palette(1)
        overlay[0] = overlay_color
        overlay_rectangle = vectorio.Rectangle(pixel_shader=overlay, width=overlay_width, height=overlay_height, x=overlay_x, y=overlay_y)
        overlay_rectangle.hidden = True
        display_group.append( overlay_rectangle )

        overlay_label_group = displayio.Group( scale=2, x=20, y=60)
        overlay_label_text = ""
        overlay_label_text_area = label.Label( terminalio.FONT, text=overlay_label_text, color=0xFFFFFF )
        overlay_label_group.append( overlay_label_text_area )
        overlay_label_group.hidden = True
        display_group.append( overlay_label_group )

        palette = displayio.Palette(1)
        palette[0] = 0xFFFFFF
        points3 = [ (123, 50), (128, 60), (123, 70), (118, 60) ]
        diamond = vectorio.Polygon(pixel_shader=palette, points=points3, x=0, y=0)
        display_group.append( diamond )
        diamond.hidden = True
        palette = displayio.Palette(1)
        palette[0] = 0x000000
        split = vectorio.Rectangle(pixel_shader=palette, height = 4, width = 10 , x=118, y=58)
        display_group.append( split )
        split.hidden = True
        
        palette = displayio.Palette(1)
        palette[0] = 0xFFFFFF
        underline = vectorio.Rectangle(pixel_shader=palette, height = 3, width = 10 , x=20, y=30)
        display_group.append( underline )
        underline.hidden = True
        
        del palette, points2, bar_color, bar, bar_width, bar_default_height
        del bands_sorted, color_label_text
        del wavelength_label_text, batch_number_label_text, recording_rectangle_width
        del recording_rectangle_height, recording_rectangle_x, recording_rectangle_y
        del recording_rectangle_color, recording, recording_label_text
        del overlay_width, overlay_height, overlay_x, overlay_y, overlay_color, overlay
        del points3

        print( "initialized graph screen" )
        return ( graph_bar, graph_bar_x, polygon, batch_number_label_text_area,
            overlay_rectangle, overlay_label_group, overlay_label_text_area,
            recording_rectangle, recording_label_text_area, diamond, split, underline)
    else:
        print( "graph screen initialization failed" )
        return False, False, False, False, False, False, False, False, False, False, False, False
